Toolchain Setup
===============

.. toctree::
   :maxdepth: 2
   :caption: Contents:

This provides information on initial setup of the toolchain when developing for carbs, information on how to use **tox** for running unit and validation tests, and for using **tox** to build documentation.

.. contents:: Table of Contents
    :depth: 2
    :local:

.. include:: ../../README.rst
    :start-after: BEGIN TOOLCHAIN INCLUDE
    :end-before: END TOOLCHAIN INCLUDE
